Package 'semnova'

Title: Analyzing Interindividual Differences in Experiments
Description: Latent repeated measures ANOVA is a structural equation modeling based alternative to traditional repeated measures ANOVA proposed by Langenberg et al. <doi:10.1080/00273171.2020.1803038> allowing to analyse ANOVA designs with latent variables.
Authors: Benedikt Langenberg [aut, cre], Axel Mayer [ctb]
Maintainer: Benedikt Langenberg <[email protected]>
License: GPL (>= 2)
Version: 0.2.2.9001
Built: 2026-06-05 08:47:02 UTC
Source: https://github.com/langenberg/semnova

Help Index


Compares the lavaan objects contained in Lgc objects.

Description

Compares the lavaan objects contained in Lgc objects.

Usage

## S3 method for class 'Lgc'
anova(object, ...)

Arguments

object

Object of class Lgc.

...

Additional arguments passed down to anova(lavaan_object, ...).


ContrastPlot class

Description

Some description

Methods

Public methods


Method new()

Usage
ContrastPlot$new()

Method plot()

Usage
ContrastPlot$plot(
  lgc,
  hypothesis,
  geom = c("line", "point"),
  interval = c("none", "sd", "ci")
)

Method clone()

The objects of this class are cloneable with this method.

Usage
ContrastPlot$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


Wrapper method for Dag$new()

Description

Wrapper method for Dag$new()

Usage

dag(lgc, ...)

Arguments

lgc

Object of class Lgc.

...

Arguments passed down to dag$plot().


Wrapper method for power$plot()

Description

Wrapper method for power$plot()

Usage

## S3 method for class 'Power'
plot(x, ...)

Arguments

x

Object of class Power.

...

Arguments passed down to power$plot().


Power class

Description

Some description

Active bindings

expose

Read only. Returns the private structure of the object. For debugging purposes only.

Methods

Public methods


Method new()

Usage
Power$new()

Method get_results()

Returns a list of detailed results.

Usage
Power$get_results()

Method power_script_lgc()

Creates a power script for the Lgc class.

Usage
Power$power_script_lgc(..., out_file = NULL, print = FALSE)

Method power_script_semnova()

Creates a power script for the Semnova class.

Usage
Power$power_script_semnova(..., out_file = NULL, print = FALSE)

Method power_analysis_lgc()

Usage
Power$power_analysis_lgc(..., data_syntax, sample_size, replications)

Method power_analysis_semnova()

Usage
Power$power_analysis_semnova(..., data_syntax, sample_size, replications)

Method print()

Prints the power for each of the model parameters.

Usage
Power$print(...)

Method summary()

Prints the power for the hypotheses.

Usage
Power$summary(...)

Method plot()

Plots the Lgc dummy object.

Usage
Power$plot(...)

Method clone()

The objects of this class are cloneable with this method.

Usage
Power$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


Wrapper method for Power$get_power_semnova_script()

Description

Wrapper method for Power$get_power_semnova_script()

Usage

power_analysis_lgc(...)

Arguments

...

Additional arugments passed to Power$get_power_semnova_script().


Wrapper method for Power$get_power_semnova_script()

Description

Wrapper method for Power$get_power_semnova_script()

Usage

power_analysis_semnova(...)

Arguments

...

Additional arugments passed to Power$get_power_semnova_script().


Wrapper method for Power$get_power_lgc_script()

Description

Wrapper method for Power$get_power_lgc_script()

Usage

power_script_lgc(...)

Arguments

...

Additional arugments passed to Power$get_power_lgc_script().


Wrapper method for Power$get_power_semnova_script()

Description

Wrapper method for Power$get_power_semnova_script()

Usage

power_script_semnova(...)

Arguments

...

Additional arugments passed to Power$get_power_semnova_script().


Wrapper method for lgc$print()

Description

Wrapper method for lgc$print()

Usage

## S3 method for class 'Lgc'
print(x, ...)

Arguments

x

Object of class Lgc.

...

Arguments passed down to lgc$print().


Wrapper method for power$print()

Description

Wrapper method for power$print()

Usage

## S3 method for class 'Lgc'
print(x, ...)

Arguments

x

Object of class Power.

...

Arguments passed down to power$print().


Example data from reading research.

Description

Example data from reading research.

Usage

reading_raw

reading_latent

reading_manifest

Format

id

Unique identifier.

dv

Continuous dependent variable. The variable is on its raw scale for reading_raw. The variable is log-transformed and standardized (grouped by indicator) for reading_latent.

indicator

Includes the names of three indicators measuring reading skills (also see gaze_dur, tv_dur and ini_fix_dur).

sentence

The type of the sentence: sentence vs. landolt.

grade

Grade variable: grade0 to grade5.

gaze_dur

Mean gaze duration per participant.

tv_dur

Mean total viewing duration per participant

ini_fix_dur

Mean initial fixation duration per participant.

age_t0

Age at grade 0.

sex

Sex.

grade_t0

Grade at grade 0. Important if participant had to repeat a year.

iq

IQ.

cbcl_ges_tw_t0

Child Behavior Checklist. Overall t-score at grade 0.

cbcl_int_verh_tw_t0

Child Behavior Checklist. Internalizing behavior t-score at grade 0.

cbcl_ext_verh_tw_t0

Child Behavior Checklist. Externalizing behavior t-score at grade 0.

cbcl_ges_rw_t0

Child Behavior Checklist. Overall raw score at grade 0.

cbcl_int_verh_rw_t0

Child Behavior Checklist. Internalizing behavior raw score at grade 0.

cbcl_ext_verh_rw_t0

Child Behavior Checklist. Externalizing behavior raw score at grade 0.

cbcl_ges_tw_t5

Child Behavior Checklist. Overall t-score at grade 5.

cbcl_int_verh_tw_t5

Child Behavior Checklist. Internalizing behavior t-score at grade 5.

cbcl_ext_verh_tw_t5

Child Behavior Checklist. Externalizing behavior t-score at grade 5.

cbcl_ges_rw_t5

Child Behavior Checklist. Overall raw score at grade 5.

cbcl_int_verh_rw_t5

Child Behavior Checklist. Internalizing behavior raw score at grade 5.

cbcl_ext_verh_rw_t5

Child Behavior Checklist. Externalizing behavior raw score at grade 5.

An object of class tbl_df (inherits from tbl, data.frame) with 4806 rows and 21 columns.

An object of class tbl_df (inherits from tbl, data.frame) with 1602 rows and 22 columns.

Details

reading_raw is the raw data in long data format.

reading_latent is based on reading_raw but the variable dv was log-transformed and standardized. The data set only includes measurements at grade 1, 2 and 4.

reading_manifest is based on reading_latent and was transposed to wide format introducing the three additional variables: gaze_dur, tv_dur and ini_fix_dur. The names for the variables were taken from indicator and the values were taken from dv.


Prints the reliabilities of the indicators of latent variables.

Description

Prints the reliabilities of the indicators of latent variables.

Usage

reliabilities(lgc)

Arguments

lgc

Object of class Lgc.


SemnovaEffect class

Description

Some description

Usage

## S3 method for class 'SemnovaEffect'
effSources(mod)

## S3 method for class 'SemnovaEffect'
formula(x, ...)

## S3 method for class 'SemnovaEffect'
family(object, ...)

## S3 method for class 'SemnovaEffect'
model.frame(object, ...)

model.offset.SemnovaEffect(object, ...)

## S3 method for class 'SemnovaEffect'
model.matrix(object, ...)

## S3 method for class 'model.frame.SemnovaEffect'
expand(model, extras, envir = environment(formula(model)), na.expand = FALSE)

## S3 method for class 'SemnovaEffect'
getCall(x, ...)

vcov.SemnovaEffect(object, complete = TRUE, ...)

## S3 method for class 'SemnovaEffect'
coefficients(object, ...)

## S3 method for class 'SemnovaEffect'
coef(object, ...)

nonest.basis(x, ...)

## S3 method for class 'SemnovaEffect'
nonest.basis(x, ...)

## S3 method for class 'SemnovaEffect'
qr(x, ...)

## S3 method for class 'SemnovaFormula'
model.matrix(object, ...)

## S3 method for class 'SemnovaFormula'
terms(x, ...)

## S3 method for class 'SemnovaFormula'
`[`(x, i)

Active bindings

expose

Read only. Returns the private structure of the object. For debugging purposes only.

Methods

Public methods


Method get_model_matrix()

Usage
SemnovaEffect$get_model_matrix(data = NULL, ...)

Method new()

Usage
SemnovaEffect$new(mod)

Method effect()

Usage
SemnovaEffect$effect(focal.predictors, interval = c("ci", "sd"), ...)

Method effSources()

Usage
SemnovaEffect$effSources()

Method clone()

The objects of this class are cloneable with this method.

Usage
SemnovaEffect$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


Wrapper method for lgc$summary()

Description

Wrapper method for lgc$summary()

Usage

## S3 method for class 'Lgc'
summary(object, ...)

Arguments

object

Object of class Lgc.

...

Arguments passed down to lgc$summary().


Wrapper method for power$summary()

Description

Wrapper method for power$summary()

Usage

## S3 method for class 'Power'
summary(x, ...)

Arguments

x

Object of class Power.

...

Arguments passed down to power$summary().


Tests a hypothesis.

Description

Tests a hypothesis.

Usage

test_hypothesis(lgc, hypothesis)

Arguments

lgc

Object of class Lgc.

hypothesis

Object of class Hypothesis.