| Title: | Analyzing Interindividual Differences in Experiments |
|---|---|
| Description: | Latent repeated measures ANOVA is a structural equation modeling based alternative to traditional repeated measures ANOVA proposed by Langenberg et al. <doi:10.1080/00273171.2020.1803038> allowing to analyse ANOVA designs with latent variables. |
| Authors: | Benedikt Langenberg [aut, cre], Axel Mayer [ctb] |
| Maintainer: | Benedikt Langenberg <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.2.2.9001 |
| Built: | 2026-06-05 08:47:02 UTC |
| Source: | https://github.com/langenberg/semnova |
Compares the lavaan objects contained in Lgc objects.
## S3 method for class 'Lgc' anova(object, ...)## S3 method for class 'Lgc' anova(object, ...)
object |
Object of class Lgc. |
... |
Additional arguments passed down to anova(lavaan_object, ...). |
Some description
new()
ContrastPlot$new()
plot()
ContrastPlot$plot(
lgc,
hypothesis,
geom = c("line", "point"),
interval = c("none", "sd", "ci")
)clone()
The objects of this class are cloneable with this method.
ContrastPlot$clone(deep = FALSE)
deepWhether to make a deep clone.
Wrapper method for Dag$new()
dag(lgc, ...)dag(lgc, ...)
lgc |
Object of class Lgc. |
... |
Arguments passed down to dag$plot(). |
Wrapper method for power$plot()
## S3 method for class 'Power' plot(x, ...)## S3 method for class 'Power' plot(x, ...)
x |
Object of class Power. |
... |
Arguments passed down to power$plot(). |
Some description
exposeRead only. Returns the private structure of the object. For debugging purposes only.
new()
Power$new()
get_results()
Returns a list of detailed results.
Power$get_results()
power_script_lgc()
Creates a power script for the Lgc class.
Power$power_script_lgc(..., out_file = NULL, print = FALSE)
power_script_semnova()
Creates a power script for the Semnova class.
Power$power_script_semnova(..., out_file = NULL, print = FALSE)
power_analysis_lgc()
Power$power_analysis_lgc(..., data_syntax, sample_size, replications)
power_analysis_semnova()
Power$power_analysis_semnova(..., data_syntax, sample_size, replications)
print()
Prints the power for each of the model parameters.
Power$print(...)
summary()
Prints the power for the hypotheses.
Power$summary(...)
plot()
Plots the Lgc dummy object.
Power$plot(...)
clone()
The objects of this class are cloneable with this method.
Power$clone(deep = FALSE)
deepWhether to make a deep clone.
Wrapper method for Power$get_power_semnova_script()
power_analysis_lgc(...)power_analysis_lgc(...)
... |
Additional arugments passed to Power$get_power_semnova_script(). |
Wrapper method for Power$get_power_semnova_script()
power_analysis_semnova(...)power_analysis_semnova(...)
... |
Additional arugments passed to Power$get_power_semnova_script(). |
Wrapper method for Power$get_power_lgc_script()
power_script_lgc(...)power_script_lgc(...)
... |
Additional arugments passed to Power$get_power_lgc_script(). |
Wrapper method for Power$get_power_semnova_script()
power_script_semnova(...)power_script_semnova(...)
... |
Additional arugments passed to Power$get_power_semnova_script(). |
Wrapper method for lgc$print()
## S3 method for class 'Lgc' print(x, ...)## S3 method for class 'Lgc' print(x, ...)
x |
Object of class Lgc. |
... |
Arguments passed down to lgc$print(). |
Wrapper method for power$print()
## S3 method for class 'Lgc' print(x, ...)## S3 method for class 'Lgc' print(x, ...)
x |
Object of class Power. |
... |
Arguments passed down to power$print(). |
Example data from reading research.
reading_raw reading_latent reading_manifestreading_raw reading_latent reading_manifest
Unique identifier.
Continuous dependent variable. The variable is on its raw scale
for reading_raw. The variable is log-transformed and
standardized (grouped by indicator) for reading_latent.
Includes the names of three indicators measuring reading skills (also see gaze_dur, tv_dur and ini_fix_dur).
The type of the sentence: sentence vs. landolt.
Grade variable: grade0 to grade5.
Mean gaze duration per participant.
Mean total viewing duration per participant
Mean initial fixation duration per participant.
Age at grade 0.
Sex.
Grade at grade 0. Important if participant had to repeat a year.
IQ.
Child Behavior Checklist. Overall t-score at grade 0.
Child Behavior Checklist. Internalizing behavior t-score at grade 0.
Child Behavior Checklist. Externalizing behavior t-score at grade 0.
Child Behavior Checklist. Overall raw score at grade 0.
Child Behavior Checklist. Internalizing behavior raw score at grade 0.
Child Behavior Checklist. Externalizing behavior raw score at grade 0.
Child Behavior Checklist. Overall t-score at grade 5.
Child Behavior Checklist. Internalizing behavior t-score at grade 5.
Child Behavior Checklist. Externalizing behavior t-score at grade 5.
Child Behavior Checklist. Overall raw score at grade 5.
Child Behavior Checklist. Internalizing behavior raw score at grade 5.
Child Behavior Checklist. Externalizing behavior raw score at grade 5.
An object of class tbl_df (inherits from tbl, data.frame) with 4806 rows and 21 columns.
An object of class tbl_df (inherits from tbl, data.frame) with 1602 rows and 22 columns.
reading_raw is the raw data in long data format.
reading_latent is based on reading_raw but the variable
dv was log-transformed and standardized. The data set only includes
measurements at grade 1, 2 and 4.
reading_manifest is based on reading_latent and was transposed
to wide format introducing the three additional variables: gaze_dur,
tv_dur and ini_fix_dur. The names for the variables were taken
from indicator and the values were taken from dv.
Prints the reliabilities of the indicators of latent variables.
reliabilities(lgc)reliabilities(lgc)
lgc |
Object of class Lgc. |
Some description
## S3 method for class 'SemnovaEffect' effSources(mod) ## S3 method for class 'SemnovaEffect' formula(x, ...) ## S3 method for class 'SemnovaEffect' family(object, ...) ## S3 method for class 'SemnovaEffect' model.frame(object, ...) model.offset.SemnovaEffect(object, ...) ## S3 method for class 'SemnovaEffect' model.matrix(object, ...) ## S3 method for class 'model.frame.SemnovaEffect' expand(model, extras, envir = environment(formula(model)), na.expand = FALSE) ## S3 method for class 'SemnovaEffect' getCall(x, ...) vcov.SemnovaEffect(object, complete = TRUE, ...) ## S3 method for class 'SemnovaEffect' coefficients(object, ...) ## S3 method for class 'SemnovaEffect' coef(object, ...) nonest.basis(x, ...) ## S3 method for class 'SemnovaEffect' nonest.basis(x, ...) ## S3 method for class 'SemnovaEffect' qr(x, ...) ## S3 method for class 'SemnovaFormula' model.matrix(object, ...) ## S3 method for class 'SemnovaFormula' terms(x, ...) ## S3 method for class 'SemnovaFormula' `[`(x, i)## S3 method for class 'SemnovaEffect' effSources(mod) ## S3 method for class 'SemnovaEffect' formula(x, ...) ## S3 method for class 'SemnovaEffect' family(object, ...) ## S3 method for class 'SemnovaEffect' model.frame(object, ...) model.offset.SemnovaEffect(object, ...) ## S3 method for class 'SemnovaEffect' model.matrix(object, ...) ## S3 method for class 'model.frame.SemnovaEffect' expand(model, extras, envir = environment(formula(model)), na.expand = FALSE) ## S3 method for class 'SemnovaEffect' getCall(x, ...) vcov.SemnovaEffect(object, complete = TRUE, ...) ## S3 method for class 'SemnovaEffect' coefficients(object, ...) ## S3 method for class 'SemnovaEffect' coef(object, ...) nonest.basis(x, ...) ## S3 method for class 'SemnovaEffect' nonest.basis(x, ...) ## S3 method for class 'SemnovaEffect' qr(x, ...) ## S3 method for class 'SemnovaFormula' model.matrix(object, ...) ## S3 method for class 'SemnovaFormula' terms(x, ...) ## S3 method for class 'SemnovaFormula' `[`(x, i)
exposeRead only. Returns the private structure of the object. For debugging purposes only.
get_model_matrix()
SemnovaEffect$get_model_matrix(data = NULL, ...)
new()
SemnovaEffect$new(mod)
effect()
SemnovaEffect$effect(focal.predictors, interval = c("ci", "sd"), ...)effSources()
SemnovaEffect$effSources()
clone()
The objects of this class are cloneable with this method.
SemnovaEffect$clone(deep = FALSE)
deepWhether to make a deep clone.
Wrapper method for lgc$summary()
## S3 method for class 'Lgc' summary(object, ...)## S3 method for class 'Lgc' summary(object, ...)
object |
Object of class Lgc. |
... |
Arguments passed down to lgc$summary(). |
Wrapper method for power$summary()
## S3 method for class 'Power' summary(x, ...)## S3 method for class 'Power' summary(x, ...)
x |
Object of class Power. |
... |
Arguments passed down to power$summary(). |
Tests a hypothesis.
test_hypothesis(lgc, hypothesis)test_hypothesis(lgc, hypothesis)
lgc |
Object of class Lgc. |
hypothesis |
Object of class Hypothesis. |